pub struct Edge<G> {
pub start: VertexId,
pub end: VertexId,
pub curve: Option<G>,
}Expand description
Edge bounded by two vertices and optionally supported by exact curve data.
Fields
start: VertexIdStart vertex.
end: VertexIdEnd vertex.
curve: Option<G>Exact support curve handle; absent for a straight topological edge whose endpoints are sufficient.